AEA applications have different requirements for _trustlessness_ or _trust minimisation_.

We can further minimise trust requirements by incorporating a third party as an <a href="https://en.wikipedia.org/wiki/Escrow" target="_blank">arbitrator or escrow</a> implemented in a <a href="https://en.wikipedia.org/wiki/Smart_contract" target="_blank">smart contract</a> to further reduce trust requirements.

<br />
